==> vscat-1.0.0.tgz: package/tests/highlighting/sources/json/npm-package/results/output.red.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test red theme 1`] = `
Object {
  "lines": Array [
    "[48;2;57;0;0m [38;2;135;63;63m 1 │ [39m[38;2;248;248;248m{[39m                                                                         [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 2 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"name\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"test-package\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 3 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"description\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"Some[39m[38;2;193;0;0m·[39m[38;2;204;140;140museful[39m[38;2;193;0;0m·[39m[38;2;204;140;140mpackage[39m[38;2;193;0;0m·[39m[38;2;204;140;140mto[39m[38;2;193;0;0m·[39m[38;2;204;140;140mdo[39m[38;2;193;0;0m·[39m[38;2;204;140;140msome[39m[38;2;193;0;0m·[39m[38;2;204;140;140museful[39m[38;2;193;0;0m·[39m[38;2;204;140;140mstuff[39m[38;2;193;0;0m·[39m[38;2;204;140;140mwith[39m[38;2;193;0;0m·[39m[38;2;204;140;140madvanc[39m[38;2;204;140;140m…[39m[49m",
    "[48;2;57;0;0m [38;2;135;63;63m 4 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"version\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"1.0.0\\"[39m[38;2;248;248;248m,[39m                                                     [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 5 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"private\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;152;70;70mtrue[39m[38;2;248;248;248m,[39m                                                        [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 6 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"license\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"MIT\\"[39m[38;2;248;248;248m,[39m                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 7 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"dependencies\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;248;248;248m{[39m                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 8 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-1\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"1.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 9 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-2\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"2.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m10 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-3\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"3.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m11 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-4\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"4.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m12 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-5\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"5.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m13 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-6\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;57;0;0m [38;2;135;63;63m14 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;248;248;248m}[39m                                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m15 │ [39m[38;2;248;248;248m}[39m                                                                         [49m",
    "[48;2;57;0;0m [38;2;135;63;63m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #F8F8F8 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #F8F8F8 │   
 1 │  2, 8 │ #9CF29E │ \\"name\\"
 1 │  8,10 │ #F8F8F8 │ : 
 1 │ 10,24 │ #CC8C8C │ \\"test-package\\"
 1 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #F8F8F8 │   
 2 │  2,15 │ #9CF29E │ \\"description\\"
 2 │ 15,17 │ #F8F8F8 │ : 
 2 │ 17,90 │ #CC8C8C │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #F8F8F8 │   
 3 │  2,11 │ #9CF29E │ \\"version\\"
 3 │ 11,13 │ #F8F8F8 │ : 
 3 │ 13,20 │ #CC8C8C │ \\"1.0.0\\"
 3 │ 20,21 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #F8F8F8 │   
 4 │  2,11 │ #9CF29E │ \\"private\\"
 4 │ 11,13 │ #F8F8F8 │ : 
 4 │ 13,17 │ #984646 │ true
 4 │ 17,18 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #F8F8F8 │   
 5 │  2,11 │ #9CF29E │ \\"license\\"
 5 │ 11,13 │ #F8F8F8 │ : 
 5 │ 13,18 │ #CC8C8C │ \\"MIT\\"
 5 │ 18,19 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #F8F8F8 │   
 6 │  2,16 │ #9CF29E │ \\"dependencies\\"
 6 │ 16,19 │ #F8F8F8 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #F8F8F8 │     
 7 │  4,15 │ #9CF29E │ \\"package-1\\"
 7 │ 15,17 │ #F8F8F8 │ : 
 7 │ 17,24 │ #CC8C8C │ \\"1.0.0\\"
 7 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #F8F8F8 │     
 8 │  4,15 │ #9CF29E │ \\"package-2\\"
 8 │ 15,17 │ #F8F8F8 │ : 
 8 │ 17,24 │ #CC8C8C │ \\"2.0.0\\"
 8 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #F8F8F8 │     
 9 │  4,15 │ #9CF29E │ \\"package-3\\"
 9 │ 15,17 │ #F8F8F8 │ : 
 9 │ 17,24 │ #CC8C8C │ \\"3.0.0\\"
 9 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #F8F8F8 │     
10 │  4,15 │ #9CF29E │ \\"package-4\\"
10 │ 15,17 │ #F8F8F8 │ : 
10 │ 17,24 │ #CC8C8C │ \\"4.0.0\\"
10 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #F8F8F8 │     
11 │  4,15 │ #9CF29E │ \\"package-5\\"
11 │ 15,17 │ #F8F8F8 │ : 
11 │ 17,24 │ #CC8C8C │ \\"5.0.0\\"
11 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #F8F8F8 │     
12 │  4,15 │ #9CF29E │ \\"package-6\\"
12 │ 15,17 │ #F8F8F8 │ : 
12 │ 17,24 │ #CC8C8C │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #F8F8F8 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #F8F8F8 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;

==> vscat-1.0.1.tgz: package/tests/highlighting/sources/json/npm-package/results/output.red.ts <==
// Jest Snapshot v1, https://goo.gl/fbAQLP

exports[`sources suite json language npm-package test red theme 1`] = `
Object {
  "lines": Array [
    "[48;2;57;0;0m [38;2;135;63;63m 1 │ [39m[38;2;248;248;248m{[39m                                                                         [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 2 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"name\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"test-package\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 3 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"description\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"Some[39m[38;2;193;0;0m·[39m[38;2;204;140;140museful[39m[38;2;193;0;0m·[39m[38;2;204;140;140mpackage[39m[38;2;193;0;0m·[39m[38;2;204;140;140mto[39m[38;2;193;0;0m·[39m[38;2;204;140;140mdo[39m[38;2;193;0;0m·[39m[38;2;204;140;140msome[39m[38;2;193;0;0m·[39m[38;2;204;140;140museful[39m[38;2;193;0;0m·[39m[38;2;204;140;140mstuff[39m[38;2;193;0;0m·[39m[38;2;204;140;140mwith[39m[38;2;193;0;0m·[39m[38;2;204;140;140madvanc…[39m[49m",
    "[48;2;57;0;0m [38;2;135;63;63m 4 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"version\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"1.0.0\\"[39m[38;2;248;248;248m,[39m                                                     [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 5 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"private\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;152;70;70mtrue[39m[38;2;248;248;248m,[39m                                                        [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 6 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"license\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"MIT\\"[39m[38;2;248;248;248m,[39m                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 7 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"dependencies\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;248;248;248m{[39m                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 8 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-1\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"1.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m 9 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-2\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"2.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m10 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-3\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"3.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m11 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-4\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"4.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m12 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-5\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"5.0.0\\"[39m[38;2;248;248;248m,[39m                                                 [49m",
    "[48;2;57;0;0m [38;2;135;63;63m13 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;156;242;158m\\"package-6\\"[39m[38;2;248;248;248m:[39m[38;2;193;0;0m·[39m[38;2;204;140;140m\\"6.0.0\\"[39m                                                  [49m",
    "[48;2;57;0;0m [38;2;135;63;63m14 │ [39m[38;2;193;0;0m·[39m[38;2;193;0;0m·[39m[38;2;248;248;248m}[39m                                                                       [49m",
    "[48;2;57;0;0m [38;2;135;63;63m15 │ [39m[38;2;248;248;248m}[39m                                                                         [49m",
    "[48;2;57;0;0m [38;2;135;63;63m16 │ [39m                                                                          [49m",
  ],
  "tokens": Array [
    "
 0 │  0, 1 │ #F8F8F8 │ {
───┼───────┼─────────┼──────────────────────────────────────────────────
 1 │  0, 2 │ #F8F8F8 │   
 1 │  2, 8 │ #9CF29E │ \\"name\\"
 1 │  8,10 │ #F8F8F8 │ : 
 1 │ 10,24 │ #CC8C8C │ \\"test-package\\"
 1 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 2 │  0, 2 │ #F8F8F8 │   
 2 │  2,15 │ #9CF29E │ \\"description\\"
 2 │ 15,17 │ #F8F8F8 │ : 
 2 │ 17,90 │ #CC8C8C │ \\"Some useful package to do some useful stuff with advanced capabilities.\\"
 2 │ 90,91 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 3 │  0, 2 │ #F8F8F8 │   
 3 │  2,11 │ #9CF29E │ \\"version\\"
 3 │ 11,13 │ #F8F8F8 │ : 
 3 │ 13,20 │ #CC8C8C │ \\"1.0.0\\"
 3 │ 20,21 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 4 │  0, 2 │ #F8F8F8 │   
 4 │  2,11 │ #9CF29E │ \\"private\\"
 4 │ 11,13 │ #F8F8F8 │ : 
 4 │ 13,17 │ #984646 │ true
 4 │ 17,18 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 5 │  0, 2 │ #F8F8F8 │   
 5 │  2,11 │ #9CF29E │ \\"license\\"
 5 │ 11,13 │ #F8F8F8 │ : 
 5 │ 13,18 │ #CC8C8C │ \\"MIT\\"
 5 │ 18,19 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 6 │  0, 2 │ #F8F8F8 │   
 6 │  2,16 │ #9CF29E │ \\"dependencies\\"
 6 │ 16,19 │ #F8F8F8 │ : {
───┼───────┼─────────┼──────────────────────────────────────────────────
 7 │  0, 4 │ #F8F8F8 │     
 7 │  4,15 │ #9CF29E │ \\"package-1\\"
 7 │ 15,17 │ #F8F8F8 │ : 
 7 │ 17,24 │ #CC8C8C │ \\"1.0.0\\"
 7 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 8 │  0, 4 │ #F8F8F8 │     
 8 │  4,15 │ #9CF29E │ \\"package-2\\"
 8 │ 15,17 │ #F8F8F8 │ : 
 8 │ 17,24 │ #CC8C8C │ \\"2.0.0\\"
 8 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
 9 │  0, 4 │ #F8F8F8 │     
 9 │  4,15 │ #9CF29E │ \\"package-3\\"
 9 │ 15,17 │ #F8F8F8 │ : 
 9 │ 17,24 │ #CC8C8C │ \\"3.0.0\\"
 9 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
10 │  0, 4 │ #F8F8F8 │     
10 │  4,15 │ #9CF29E │ \\"package-4\\"
10 │ 15,17 │ #F8F8F8 │ : 
10 │ 17,24 │ #CC8C8C │ \\"4.0.0\\"
10 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
11 │  0, 4 │ #F8F8F8 │     
11 │  4,15 │ #9CF29E │ \\"package-5\\"
11 │ 15,17 │ #F8F8F8 │ : 
11 │ 17,24 │ #CC8C8C │ \\"5.0.0\\"
11 │ 24,25 │ #F8F8F8 │ ,
───┼───────┼─────────┼──────────────────────────────────────────────────
12 │  0, 4 │ #F8F8F8 │     
12 │  4,15 │ #9CF29E │ \\"package-6\\"
12 │ 15,17 │ #F8F8F8 │ : 
12 │ 17,24 │ #CC8C8C │ \\"6.0.0\\"
───┼───────┼─────────┼──────────────────────────────────────────────────
13 │  0, 3 │ #F8F8F8 │   }
───┼───────┼─────────┼──────────────────────────────────────────────────
14 │  0, 1 │ #F8F8F8 │ }
───┼───────┼─────────┼──────────────────────────────────────────────────
15 │ none  │         │
",
  ],
}
`;
